==> monodevelop-database_1.0+dfsg.orig.tar.gz: monodevelop-database-1.0+dfsg/MonoDevelop.Database.Sql/Schema/ProcedureSchema.cs <==
//
// Authors:
//	Christian Hergert  <chris@mosaix.net>
//	Ben Motmans  <ben.motmans@gmail.com>
//
// Copyright (C) 2005 Mosaix Communications, Inc.
// Copyright (c) 2007 Ben Motmans
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.Collections.Generic;

namespace MonoDevelop.Database.Sql
{
	public class ProcedureSchema : AbstractSchema
	{
		protected ParameterSchemaCollection parameters;
		protected string language;
		protected bool isSystemProcedure = false;
		
		public ProcedureSchema (ISchemaProvider schemaProvider)
			: base (schemaProvider)
		{
		}
		
		public ProcedureSchema (ProcedureSchema proc)
			: base (proc)
		{
			this.parameters = new ParameterSchemaCollection (parameters);
			this.language = proc.language;
			this.isSystemProcedure = proc.isSystemProcedure;
		}
		
		public ParameterSchemaCollection Parameters {
			get {
				if (parameters == null)
					parameters = provider.GetProcedureParameters (this);
				return parameters;
			}
		}
		
		public LanguageSchema Language {
			get {
				throw new NotImplementedException();
			}
			set {
				language = value.FullName;
			}
		}
		
		public string LanguageName {
			get {
				return language;
			}
			set {
				if (language != value) {
					language = value;
					OnChanged ();
				}
			}
		}
		
		public bool IsSystemProcedure {
			get {
				return isSystemProcedure;
			}
			set {
				if (isSystemProcedure != value) {
					isSystemProcedure = value;
					OnChanged ();
				}
			}
		}
		
		public override object Clone ()
		{
			return new ProcedureSchema (this);
		}
	}
}

==> monodevelop-database_4.0.12+dfsg.orig.tar.gz: monodevelop-database-4.0.12/MonoDevelop.Database.Sql/Schema/ProcedureSchema.cs <==
//
// Authors:
//	Christian Hergert  <chris@mosaix.net>
//	Ben Motmans  <ben.motmans@gmail.com>
//
// Copyright (C) 2005 Mosaix Communications, Inc.
// Copyright (c) 2007 Ben Motmans
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.Collections.Generic;

namespace MonoDevelop.Database.Sql
{
	public class ProcedureSchema : AbstractSchema
	{
		protected ParameterSchemaCollection parameters;
		protected string language;
		protected bool isSystemProcedure = false;
		protected bool isFunction = false;
		
		public ProcedureSchema (ISchemaProvider schemaProvider)
			: base (schemaProvider)
		{
		}
		
		public ProcedureSchema (ProcedureSchema proc)
			: base (proc)
		{
			this.parameters = new ParameterSchemaCollection (parameters);
			this.language = proc.language;
			this.isSystemProcedure = proc.isSystemProcedure;
		}
		
		public ParameterSchemaCollection Parameters {
			get {
				if (parameters == null)
					parameters = provider.GetProcedureParameters (this);
				return parameters;
			}
		}
		
		public LanguageSchema Language {
			get {
				throw new NotImplementedException();
			}
			set {
				language = value.FullName;
			}
		}
		
		public string LanguageName {
			get {
				return language;
			}
			set {
				if (language != value) {
					language = value;
					OnChanged ();
				}
			}
		}
		
		public bool IsSystemProcedure {
			get {
				return isSystemProcedure;
			}
			set {
				if (isSystemProcedure != value) {
					isSystemProcedure = value;
					OnChanged ();
				}
			}
		}
		
		public bool IsFunction {
			get {
				return isFunction;
			} 
			set {
				if (isFunction != value) {
					isFunction = value;
					OnChanged ();
				}
			}
		}
		
		public override object Clone ()
		{
			return new ProcedureSchema (this);
		}
	}
}
